Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(135)

Unified Diff: pkg/compiler/lib/src/common/backend_api.dart

Issue 1651933002: Report error on JS-interop operator [] and []= methods. (Closed) Base URL: https://github.com/dart-lang/sdk.git@master
Patch Set: Sort MessageKinds. Created 4 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | pkg/compiler/lib/src/diagnostics/messages.dart » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: pkg/compiler/lib/src/common/backend_api.dart
diff --git a/pkg/compiler/lib/src/common/backend_api.dart b/pkg/compiler/lib/src/common/backend_api.dart
index d2fa5ec96cc6139b48bad64caf247adb783a6ad7..306361621ea9934a2652ce67f9f111d2b02b1fac 100644
--- a/pkg/compiler/lib/src/common/backend_api.dart
+++ b/pkg/compiler/lib/src/common/backend_api.dart
@@ -31,7 +31,8 @@ import '../elements/elements.dart' show
Element,
FunctionElement,
LibraryElement,
- MetadataAnnotation;
+ MetadataAnnotation,
+ MethodElement;
import '../enqueue.dart' show
Enqueuer,
CodegenEnqueuer,
@@ -282,9 +283,9 @@ abstract class Backend {
return native.maybeEnableNative(compiler, library);
}
/// Processes [element] for resolution and returns the [FunctionElement] that
/// defines the implementation of [element].
- FunctionElement resolveExternalFunction(FunctionElement element) => element;
+ MethodElement resolveExternalFunction(MethodElement element) => element;
/// Returns `true` if [library] is a backend specific library whose members
/// have special treatment, such as being allowed to extends blacklisted
« no previous file with comments | « no previous file | pkg/compiler/lib/src/diagnostics/messages.dart » ('j') | no next file with comments »
@@ -282,9 +283,9 @@ abstract class Backend {
return native.maybeEnableNative(compiler, library);
}
- /// Processes [element] for resolution and returns the [FunctionElement] that
+ /// Processes [element] for resolution and returns the [MethodElement] that
/// defines the implementation of [element].

Powered by Google App Engine
This is Rietveld 408576698